Class: Google::Cloud::BinaryAuthorization::V1beta1::AdmissionWhitelistPattern
- Inherits:
-
Object
- Object
- Google::Cloud::BinaryAuthorization::V1beta1::AdmissionWhitelistPattern
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/binaryauthorization/v1beta1/resources.rb
Overview
An admission whitelist pattern exempts images from checks by admission rules.
Instance Attribute Summary collapse
-
#name_pattern ⇒ ::String
An image name pattern to whitelist, in the form
registry/path/to/image.
Instance Attribute Details
#name_pattern ⇒ ::String
Returns An image name pattern to whitelist, in the form registry/path/to/image.
This supports a trailing * as a wildcard, but this is allowed only in
text after the registry/ part.
91 92 93 94 |
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/resources.rb', line 91 class AdmissionWhitelistPattern include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |