Class: Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb

Overview

Client for the BinauthzManagementService service.

Google Cloud Management Service for Binary Authorization admission policies and attestation authorities.

This API implements a REST model with the following objects:

Defined Under Namespace

Classes: Configuration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#attestor_path, #policy_path, #project_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new BinauthzManagementService client object.

Examples:


# Create a client using the default configuration
client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a client using a custom configuration
client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the BinauthzManagementService client.

Yield Parameters:



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 163

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/binaryauthorization/v1beta1/service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the endpoint is unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.endpoint.nil? ||
                           (@config.endpoint == Configuration::DEFAULT_ENDPOINT &&
                           !@config.endpoint.split(".").first.include?("-"))
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(::String) || credentials.is_a?(::Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @binauthz_management_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementServiceV1Beta1::Stub,
    credentials: credentials,
    endpoint: @config.endpoint,
    endpoint_template: DEFAULT_ENDPOINT_TEMPLATE,
    universe_domain: @config.universe_domain,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors,
    channel_pool_config: @config.channel_pool,
    logger: @config.logger
  )

  @binauthz_management_service_stub.stub_logger&.info do |entry|
    entry.set_system_name
    entry.set_service
    entry.message = "Created client for #{entry.service}"
    entry.set_credentials_fields credentials
    entry.set "customEndpoint", @config.endpoint if @config.endpoint
    entry.set "defaultTimeout", @config.timeout if @config.timeout
    entry.set "quotaProject", @quota_project_id if @quota_project_id
  end

  @iam_policy_client = Google::Iam::V1::IAMPolicy::Client.new do |config|
    config.credentials = credentials
    config.quota_project = @quota_project_id
    config.endpoint = @binauthz_management_service_stub.endpoint
    config.universe_domain = @binauthz_management_service_stub.universe_domain
    config.logger = @binauthz_management_service_stub.logger if config.respond_to? :logger=
  end
end

Instance Attribute Details

#iam_policy_clientGoogle::Iam::V1::IAMPolicy::Client (readonly)

Get the associated client for mix-in of the IAMPolicy.

Returns:

  • (Google::Iam::V1::IAMPolicy::Client)


227
228
229
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 227

def iam_policy_client
  @iam_policy_client
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the BinauthzManagementService Client class.

See Configuration for a description of the configuration fields.

Examples:


# Modify the configuration for all BinauthzManagementService clients
::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 69

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "BinaryAuthorization", "V1beta1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_policy.timeout = 600.0
    default_config.rpcs.get_policy.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.update_policy.timeout = 600.0
    default_config.rpcs.update_policy.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.create_attestor.timeout = 600.0

    default_config.rpcs.get_attestor.timeout = 600.0
    default_config.rpcs.get_attestor.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.update_attestor.timeout = 600.0
    default_config.rpcs.update_attestor.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.list_attestors.timeout = 600.0
    default_config.rpcs.list_attestors.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config.rpcs.delete_attestor.timeout = 600.0
    default_config.rpcs.delete_attestor.retry_policy = {
      initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the BinauthzManagementService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config)

    Configure the Client client.

Yield Parameters:

Returns:



133
134
135
136
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 133

def configure
  yield @config if block_given?
  @config
end

#create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Creates an attestor, and returns a copy of the new attestor. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed, ALREADY_EXISTS if the attestor already exists.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest.new

# Call the create_attestor method.
result = client.create_attestor request

# The returned object is of type Google::Cloud::BinaryAuthorization::V1beta1::Attestor.
p result

Overloads:

  • #create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to create_attestor via a request object, either of type CreateAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to create_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The parent of this attestor.

    • attestor_id (::String) (defaults to: nil)

      Required. The attestors ID.

    • attestor (::Google::Cloud::BinaryAuthorization::V1beta1::Attestor, ::Hash) (defaults to: nil)

      Required. The initial attestor value. The service will overwrite the [attestor name][google.cloud.binaryauthorization.v1beta1.Attestor.name] field with the resource name, in the format projects/*/attestors/*.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 491

def create_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_attestor..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_attestor.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :create_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes an attestor. Returns NOT_FOUND if the attestor does not exist.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest.new

# Call the delete_attestor method.
result = client.delete_attestor request

# The returned object is of type Google::Protobuf::Empty.
p result

Overloads:

  • #delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_attestor via a request object, either of type DeleteAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the attestors to delete, in the format projects/*/attestors/*.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 866

def delete_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_attestor..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_attestor.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :delete_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Gets an attestor. Returns NOT_FOUND if the attestor does not exist.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest.new

# Call the get_attestor method.
result = client.get_attestor request

# The returned object is of type Google::Cloud::BinaryAuthorization::V1beta1::Attestor.
p result

Overloads:

  • #get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to get_attestor via a request object, either of type GetAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to get_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The name of the attestor to retrieve, in the format projects/*/attestors/*.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 581

def get_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_attestor..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_attestor.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :get_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

A policy specifies the attestors that must attest to a container image, before the project is allowed to deploy that image. There is at most one policy per project. All image admission requests are permitted if a project has no policy.

Gets the policy for this project. Returns a default policy if the project does not have one.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest.new

# Call the get_policy method.
result = client.get_policy request

# The returned object is of type Google::Cloud::BinaryAuthorization::V1beta1::Policy.
p result

Overloads:

  • #get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to get_policy via a request object, either of type GetPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to get_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil)

      Required. The resource name of the policy to retrieve, in the format projects/*/policy.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 295

def get_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.name
    header_params["name"] = request.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :get_policy, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_attestors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor> #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

Lists attestors. Returns INVALID_ARGUMENT if the project does not exist.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest.new

# Call the list_attestors method.
result = client.list_attestors request

# The returned object is of type Gapic::PagedEnumerable. You can iterate
# over elements, and API calls will be issued to fetch pages as needed.
result.each do |item|
  # Each element is of type ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor.
  p item
end

Overloads:

  • #list_attestors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

    Pass arguments to list_attestors via a request object, either of type ListAttestorsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

    Pass arguments to list_attestors via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil)

      Required. The resource name of the project associated with the attestors, in the format projects/*.

    • page_size (::Integer) (defaults to: nil)

      Requested page size. The server may return fewer results than requested. If unspecified, the server will pick an appropriate default.

    • page_token (::String) (defaults to: nil)

      A token identifying a page of results the server should return. Typically, this is the value of ListAttestorsResponse.next_page_token returned from the previous call to the ListAttestors method.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 774

def list_attestors request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_attestors..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.parent
    header_params["parent"] = request.parent
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_attestors.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_attestors.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :list_attestors, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @binauthz_management_service_stub, :list_attestors, request, response, operation, options
    yield response, operation if block_given?
    throw :response, response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#loggerLogger

The logger used for request/response debug logging.

Returns:

  • (Logger)


234
235
236
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 234

def logger
  @binauthz_management_service_stub.logger
end

#universe_domainString

The effective universe domain

Returns:

  • (String)


143
144
145
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 143

def universe_domain
  @binauthz_management_service_stub.universe_domain
end

#update_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #update_attestor(attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Updates an attestor. Returns NOT_FOUND if the attestor does not exist.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::UpdateAttestorRequest.new

# Call the update_attestor method.
result = client.update_attestor request

# The returned object is of type Google::Cloud::BinaryAuthorization::V1beta1::Attestor.
p result

Overloads:

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 674

def update_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdateAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_attestor..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.attestor&.name
    header_params["attestor.name"] = request.attestor.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_attestor.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :update_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

Creates or updates a project's policy, and returns a copy of the new policy. A policy is always updated as a whole, to avoid race conditions with concurrent policy enforcement (or management!) requests. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed.

Examples:

Basic example

require "google/cloud/binary_authorization/v1beta1"

# Create a client object. The client can be reused for multiple calls.
client = Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

# Create a request. To set request fields, pass in keyword arguments.
request = Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest.new

# Call the update_policy method.
result = client.update_policy request

# The returned object is of type Google::Cloud::BinaryAuthorization::V1beta1::Policy.
p result

Overloads:

  • #update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to update_policy via a request object, either of type UpdatePolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest, ::Hash)

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil)

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to update_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • policy (::Google::Cloud::BinaryAuthorization::V1beta1::Policy, ::Hash) (defaults to: nil)

      Required. A new or updated policy value. The service will overwrite the [policy name][google.cloud.binaryauthorization.v1beta1.Policy.name] field with the resource name in the request URL, in the format projects/*/policy.

Yields:

  • (response, operation)

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error)

    if the RPC is aborted.



390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 390

def update_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_policy..to_h

  # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty?
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {}
  if request.policy&.name
    header_params["policy.name"] = request.policy.name
  end

  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_policy.retry_policy

  options.apply_defaults timeout:      @config.timeout,
                         metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :update_policy, request, options: options do |response, operation|
    yield response, operation if block_given?
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end