Class: Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb

Overview

Represents an auditing event from Continuous Validation.

Defined Under Namespace

Classes: ContinuousValidationPodEvent, UnsupportedPolicyEvent

Instance Attribute Summary collapse

Instance Attribute Details

#pod_event ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent

Returns Pod event.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 31

class ContinuousValidationEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An auditing event for one Pod.
  # @!attribute [rw] pod
  #   @return [::String]
  #     The name of the Pod.
  # @!attribute [rw] deploy_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Deploy time of the Pod from k8s.
  # @!attribute [rw] end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Termination time of the Pod from k8s, or nothing if still running.
  # @!attribute [rw] verdict
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::PolicyConformanceVerdict]
  #     Auditing verdict for this Pod.
  # @!attribute [rw] images
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails>]
  #     List of images with auditing details.
  class ContinuousValidationPodEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Container image with auditing details.
    # @!attribute [rw] image
    #   @return [::String]
    #     The name of the image.
    # @!attribute [rw] result
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
    #     The result of the audit for this image.
    # @!attribute [rw] description
    #   @return [::String]
    #     Description of the above result.
    class ImageDetails
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Result of the audit.
      module AuditResult
        # Unspecified result. This is an error.
        AUDIT_RESULT_UNSPECIFIED = 0

        # Image is allowed.
        ALLOW = 1

        # Image is denied.
        DENY = 2
      end
    end

    # Audit time policy conformance verdict.
    module PolicyConformanceVerdict
      # We should always have a verdict. This is an error.
      POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

      # The pod violates the policy.
      VIOLATES_POLICY = 1
    end
  end

  # An event describing that the project policy is unsupported by CV.
  # @!attribute [rw] description
  #   @return [::String]
  #     A description of the unsupported policy.
  class UnsupportedPolicyEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#unsupported_policy_event ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::UnsupportedPolicyEvent

Returns Unsupported policy event.



31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 31

class ContinuousValidationEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # An auditing event for one Pod.
  # @!attribute [rw] pod
  #   @return [::String]
  #     The name of the Pod.
  # @!attribute [rw] deploy_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Deploy time of the Pod from k8s.
  # @!attribute [rw] end_time
  #   @return [::Google::Protobuf::Timestamp]
  #     Termination time of the Pod from k8s, or nothing if still running.
  # @!attribute [rw] verdict
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::PolicyConformanceVerdict]
  #     Auditing verdict for this Pod.
  # @!attribute [rw] images
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails>]
  #     List of images with auditing details.
  class ContinuousValidationPodEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # Container image with auditing details.
    # @!attribute [rw] image
    #   @return [::String]
    #     The name of the image.
    # @!attribute [rw] result
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
    #     The result of the audit for this image.
    # @!attribute [rw] description
    #   @return [::String]
    #     Description of the above result.
    class ImageDetails
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # Result of the audit.
      module AuditResult
        # Unspecified result. This is an error.
        AUDIT_RESULT_UNSPECIFIED = 0

        # Image is allowed.
        ALLOW = 1

        # Image is denied.
        DENY = 2
      end
    end

    # Audit time policy conformance verdict.
    module PolicyConformanceVerdict
      # We should always have a verdict. This is an error.
      POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

      # The pod violates the policy.
      VIOLATES_POLICY = 1
    end
  end

  # An event describing that the project policy is unsupported by CV.
  # @!attribute [rw] description
  #   @return [::String]
  #     A description of the unsupported policy.
  class UnsupportedPolicyEvent
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end