Class: Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb

Overview

An auditing event for one Pod.

Defined Under Namespace

Modules: PolicyConformanceVerdict Classes: ImageDetails

Instance Attribute Summary collapse

Instance Attribute Details

#deploy_time::Google::Protobuf::Timestamp



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#end_time::Google::Protobuf::Timestamp



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#images::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails>



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#pod::String



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#pod_namespace::String



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#policy_name::String



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end

#verdict::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::PolicyConformanceVerdict



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 61

class ContinuousValidationPodEvent
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Container image with auditing details.
  # @!attribute [rw] image
  #   @return [::String]
  #     The name of the image.
  # @!attribute [rw] container_name
  #   @return [::String]
  #     The name of the container.
  # @!attribute [rw] container_type
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::ContainerType]
  #     The container type that this image belongs to.
  # @!attribute [rw] result
  #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::AuditResult]
  #     The result of the audit for this image.
  # @!attribute [rw] description
  #   @return [::String]
  #     Description of the above result.
  # @!attribute [rw] check_results
  #   @return [::Array<::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult>]
  #     List of check results.
  class ImageDetails
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods

    # @!attribute [rw] check_set_index
    #   @return [::String]
    #     The index of the check set.
    # @!attribute [rw] check_set_name
    #   @return [::String]
    #     The name of the check set.
    # @!attribute [rw] check_set_scope
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope]
    #     The scope of the check set.
    # @!attribute [rw] check_index
    #   @return [::String]
    #     The index of the check.
    # @!attribute [rw] check_name
    #   @return [::String]
    #     The name of the check.
    # @!attribute [rw] check_type
    #   @return [::String]
    #     The type of the check.
    # @!attribute [rw] verdict
    #   @return [::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict]
    #     The verdict of this check.
    # @!attribute [rw] explanation
    #   @return [::String]
    #     User-friendly explanation of this check result.
    class CheckResult
      include ::Google::Protobuf::MessageExts
      extend ::Google::Protobuf::MessageExts::ClassMethods

      # A scope specifier for check sets.
      # @!attribute [rw] kubernetes_service_account
      #   @return [::String]
      #     Matches a single Kubernetes service account, e.g.
      #     'my-namespace:my-service-account'.
      #     `kubernetes_service_account` scope is always more specific than
      #     `kubernetes_namespace` scope for the same namespace.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_service_account`, `kubernetes_namespace`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      # @!attribute [rw] kubernetes_namespace
      #   @return [::String]
      #     Matches all Kubernetes service accounts in the provided
      #     namespace, unless a more specific `kubernetes_service_account`
      #     scope already matched.
      #
      #     Note: The following fields are mutually exclusive: `kubernetes_namespace`, `kubernetes_service_account`. If a field in that set is populated, all other fields in the set will automatically be cleared.
      class CheckSetScope
        include ::Google::Protobuf::MessageExts
        extend ::Google::Protobuf::MessageExts::ClassMethods
      end

      # Result of evaluating one check.
      module CheckVerdict
        # We should always have a verdict. This is an error.
        CHECK_VERDICT_UNSPECIFIED = 0

        # The check was successfully evaluated and the image did not satisfy
        # the check.
        NON_CONFORMANT = 1
      end
    end

    # The container type.
    module ContainerType
      # The container type should always be specified. This is an error.
      CONTAINER_TYPE_UNSPECIFIED = 0

      # A regular deployment.
      CONTAINER = 1

      # Init container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/init-containers/
      INIT_CONTAINER = 2

      # Ephemeral container defined as specified at
      # https://kubernetes.io/docs/concepts/workloads/pods/ephemeral-containers/
      EPHEMERAL_CONTAINER = 3
    end

    # Result of the audit.
    module AuditResult
      # Unspecified result. This is an error.
      AUDIT_RESULT_UNSPECIFIED = 0

      # Image is allowed.
      ALLOW = 1

      # Image is denied.
      DENY = 2
    end
  end

  # Audit time policy conformance verdict.
  module PolicyConformanceVerdict
    # We should always have a verdict. This is an error.
    POLICY_CONFORMANCE_VERDICT_UNSPECIFIED = 0

    # The pod violates the policy.
    VIOLATES_POLICY = 1
  end
end