Class: Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb

Defined Under Namespace

Modules: CheckVerdict Classes: CheckSetScope

Instance Attribute Summary collapse

Instance Attribute Details

#check_index ⇒ ::String

Returns The index of the check.

Returns:

  • (::String) —

    The index of the check.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#check_name ⇒ ::String

Returns The name of the check.

Returns:

  • (::String) —

    The name of the check.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#check_set_index ⇒ ::String

Returns The index of the check set.

Returns:

  • (::String) —

    The index of the check set.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#check_set_name ⇒ ::String

Returns The name of the check set.

Returns:

  • (::String) —

    The name of the check set.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#check_set_scope ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckSetScope

Returns The scope of the check set.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#check_type ⇒ ::String

Returns The type of the check.

Returns:

  • (::String) —

    The type of the check.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#explanation ⇒ ::String

Returns User-friendly explanation of this check result.

Returns:

  • (::String) —

    User-friendly explanation of this check result.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end

#verdict ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::ContinuousValidationEvent::ContinuousValidationPodEvent::ImageDetails::CheckResult::CheckVerdict

Returns The verdict of this check.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'proto_docs/google/cloud/binaryauthorization/v1beta1/continuous_validation_logging.rb', line 102

class CheckResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # A scope specifier for check sets.
  # @!attribute [rw] kubernetes_service_account
  #   @return [::String]
  #     Matches a single Kubernetes service account, e.g.
  #     'my-namespace:my-service-account'.
  #     `kubernetes_service_account` scope is always more specific than
  #     `kubernetes_namespace` scope for the same namespace.
  # @!attribute [rw] kubernetes_namespace
  #   @return [::String]
  #     Matches all Kubernetes service accounts in the provided
  #     namespace, unless a more specific `kubernetes_service_account`
  #     scope already matched.
  class CheckSetScope
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end

  # Result of evaluating one check.
  module CheckVerdict
    # We should always have a verdict. This is an error.
    CHECK_VERDICT_UNSPECIFIED = 0

    # The check was successfully evaluated and the image did not satisfy
    # the check.
    NON_CONFORMANT = 1
  end
end