Class: Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client

Inherits:
Object
  • Object
show all
Includes:
Paths
Defined in:
lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb

Overview

Client for the BinauthzManagementService service.

Google Cloud Management Service for Binary Authorization admission policies and attestation authorities.

This API implements a REST model with the following objects:

Defined Under Namespace

Classes: Configuration

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Paths

#attestor_path, #policy_path, #project_path

Constructor Details

#initialize {|config| ... } ⇒ Client

Create a new BinauthzManagementService client object.

Examples

To create a new BinauthzManagementService client with the default configuration:

client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new

To create a new BinauthzManagementService client with a custom configuration:

client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the BinauthzManagementService client.

Yield Parameters:



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 170

def initialize
  # These require statements are intentionally placed here to initialize
  # the gRPC module only when it's required.
  # See https://github.com/googleapis/toolkit/issues/446
  require "gapic/grpc"
  require "google/cloud/binaryauthorization/v1beta1/service_services_pb"

  # Create the configuration object
  @config = Configuration.new Client.configure

  # Yield the configuration if needed
  yield @config if block_given?

  # Create credentials
  credentials = @config.credentials
  # Use self-signed JWT if the scope and endpoint are unchanged from default,
  # but only if the default endpoint does not have a region prefix.
  enable_self_signed_jwt = @config.scope == Client.configure.scope &&
                           @config.endpoint == Client.configure.endpoint &&
                           !@config.endpoint.split(".").first.include?("-")
  credentials ||= Credentials.default scope: @config.scope,
                                      enable_self_signed_jwt: enable_self_signed_jwt
  if credentials.is_a?(String) || credentials.is_a?(Hash)
    credentials = Credentials.new credentials, scope: @config.scope
  end
  @quota_project_id = @config.quota_project
  @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id

  @binauthz_management_service_stub = ::Gapic::ServiceStub.new(
    ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementServiceV1Beta1::Stub,
    credentials:  credentials,
    endpoint:     @config.endpoint,
    channel_args: @config.channel_args,
    interceptors: @config.interceptors
  )
end

Class Method Details

.configure {|config| ... } ⇒ Client::Configuration

Configure the BinauthzManagementService Client class.

See Configuration for a description of the configuration fields.

Example

To modify the configuration for all BinauthzManagementService clients:

::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.configure do |config|
  config.timeout = 10.0
end

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 63

def self.configure
  @configure ||= begin
    namespace = ["Google", "Cloud", "BinaryAuthorization", "V1beta1"]
    parent_config = while namespace.any?
                      parent_name = namespace.join "::"
                      parent_const = const_get parent_name
                      break parent_const.configure if parent_const.respond_to? :configure
                      namespace.pop
                    end
    default_config = Client::Configuration.new parent_config

    default_config.rpcs.get_policy.timeout = 600.0
    default_config.rpcs.get_policy.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config.rpcs.update_policy.timeout = 600.0
    default_config.rpcs.update_policy.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config.rpcs.create_attestor.timeout = 600.0

    default_config.rpcs.get_attestor.timeout = 600.0
    default_config.rpcs.get_attestor.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config.rpcs.update_attestor.timeout = 600.0
    default_config.rpcs.update_attestor.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config.rpcs.list_attestors.timeout = 600.0
    default_config.rpcs.list_attestors.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config.rpcs.delete_attestor.timeout = 600.0
    default_config.rpcs.delete_attestor.retry_policy = {
      initial_delay: 0.1,
  max_delay: 60.0,
  multiplier: 1.3,
  retry_codes: [4, 14]
    }

    default_config
  end
  yield @configure if block_given?
  @configure
end

Instance Method Details

#configure {|config| ... } ⇒ Client::Configuration

Configure the BinauthzManagementService Client instance.

The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.

See Configuration for a description of the configuration fields.

Yields:

  • (config) —

    Configure the Client client.

Yield Parameters:

Returns:



145
146
147
148
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 145

def configure
  yield @config if block_given?
  @config
end

#create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Creates an attestor, and returns a copy of the new attestor. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed, ALREADY_EXISTS if the attestor already exists.

Overloads:

  • #create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to create_attestor via a request object, either of type CreateAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to create_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil) —

      Required. The parent of this attestor.

    • attestor_id (::String) (defaults to: nil) —

      Required. The attestors ID.

    • attestor (::Google::Cloud::BinaryAuthorization::V1beta1::Attestor, ::Hash) (defaults to: nil) —

      Required. The initial attestor value. The service will overwrite the [attestor name][google.cloud.binaryauthorization.v1beta1.Attestor.name] field with the resource name, in the format projects/*/attestors/*.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 407

def create_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.create_attestor..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "parent" => request.parent
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.create_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.create_attestor.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :create_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty

Deletes an attestor. Returns NOT_FOUND if the attestor does not exist.

Overloads:

  • #delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_attestor via a request object, either of type DeleteAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty

    Pass arguments to delete_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil) —

      Required. The name of the attestors to delete, in the format projects/*/attestors/*.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 701

def delete_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.delete_attestor..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "name" => request.name
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.delete_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.delete_attestor.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :delete_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Gets an attestor. Returns NOT_FOUND if the attestor does not exist.

Overloads:

  • #get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to get_attestor via a request object, either of type GetAttestorRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

    Pass arguments to get_attestor via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil) —

      Required. The name of the attestor to retrieve, in the format projects/*/attestors/*.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 478

def get_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_attestor..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "name" => request.name
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_attestor.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :get_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

A policy specifies the attestors that must attest to a container image, before the project is allowed to deploy that image. There is at most one policy per project. All image admission requests are permitted if a project has no policy.

Gets the policy for this project. Returns a default policy if the project does not have one.

Overloads:

  • #get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to get_policy via a request object, either of type GetPolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to get_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • name (::String) (defaults to: nil) —

      Required. The resource name of the policy to retrieve, in the format projects/*/policy.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 249

def get_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.get_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "name" => request.name
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.get_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.get_policy.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :get_policy, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#list_attestors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor> #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

Lists attestors. Returns INVALID_ARGUMENT if the project does not exist.

Overloads:

  • #list_attestors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

    Pass arguments to list_attestors via a request object, either of type ListAttestorsRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>

    Pass arguments to list_attestors via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • parent (::String) (defaults to: nil) —

      Required. The resource name of the project associated with the attestors, in the format projects/*.

    • page_size (::Integer) (defaults to: nil) —

      Requested page size. The server may return fewer results than requested. If unspecified, the server will pick an appropriate default.

    • page_token (::String) (defaults to: nil) —

      A token identifying a page of results the server should return. Typically, this is the value of ListAttestorsResponse.next_page_token returned from the previous call to the ListAttestors method.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 629

def list_attestors request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.list_attestors..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "parent" => request.parent
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.list_attestors.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.list_attestors.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :list_attestors, request, options: options do |response, operation|
    response = ::Gapic::PagedEnumerable.new @binauthz_management_service_stub, :list_attestors, request, response, operation, options
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #update_attestor(attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor

Updates an attestor. Returns NOT_FOUND if the attestor does not exist.

Overloads:

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 552

def update_attestor request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdateAttestorRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_attestor..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "attestor.name" => request.attestor.name
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_attestor.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_attestor.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :update_attestor, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end

#update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

Creates or updates a project's policy, and returns a copy of the new policy. A policy is always updated as a whole, to avoid race conditions with concurrent policy enforcement (or management!) requests. Returns NOT_FOUND if the project does not exist, INVALID_ARGUMENT if the request is malformed.

Overloads:

  • #update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to update_policy via a request object, either of type UpdatePolicyRequest or an equivalent Hash.

    Parameters:

    • request (::Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest, ::Hash) —

      A request object representing the call parameters. Required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash.

    • options (::Gapic::CallOptions, ::Hash) (defaults to: nil) —

      Overrides the default settings for this call, e.g, timeout, retries, etc. Optional.

  • #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy

    Pass arguments to update_policy via keyword arguments. Note that at least one keyword argument is required. To specify no parameters, or to keep all the default parameter values, pass an empty Hash as a request object (see above).

    Parameters:

    • policy (::Google::Cloud::BinaryAuthorization::V1beta1::Policy, ::Hash) (defaults to: nil) —

      Required. A new or updated policy value. The service will overwrite the [policy name][google.cloud.binaryauthorization.v1beta1.Policy.name] field with the resource name in the request URL, in the format projects/*/policy.

Yields:

  • (response, operation) —

    Access the result along with the RPC operation

Yield Parameters:

Returns:

Raises:

  • (::Google::Cloud::Error) —

    if the RPC is aborted.



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 325

def update_policy request, options = nil
  raise ::ArgumentError, "request must be provided" if request.nil?

  request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest

  # Converts hash and nil to an options object
  options = ::Gapic::CallOptions.new(**options.to_h) if options.respond_to? :to_h

  # Customize the options with defaults
   = @config.rpcs.update_policy..to_h

  # Set x-goog-api-client and x-goog-user-project headers
  [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \
    lib_name: @config.lib_name, lib_version: @config.lib_version,
    gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION
  [:"x-goog-user-project"] = @quota_project_id if @quota_project_id

  header_params = {
    "policy.name" => request.policy.name
  }
  request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&")
  [:"x-goog-request-params"] ||= request_params_header

  options.apply_defaults timeout:      @config.rpcs.update_policy.timeout,
                         metadata:     ,
                         retry_policy: @config.rpcs.update_policy.retry_policy
  options.apply_defaults metadata:     @config.,
                         retry_policy: @config.retry_policy

  @binauthz_management_service_stub.call_rpc :update_policy, request, options: options do |response, operation|
    yield response, operation if block_given?
    return response
  end
rescue ::GRPC::BadStatus => e
  raise ::Google::Cloud::Error.from_error(e)
end