Class: Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client
- Inherits:
-
Object
- Object
- Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb
Overview
Defined Under Namespace
Classes: Configuration
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client instance.
- #create_attestor(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
-
#delete_attestor(request, options = nil) {|response, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes an attestor.
-
#get_attestor(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
Gets an attestor.
- #get_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new BinauthzManagementService client object.
-
#list_attestors(request, options = nil) {|response, operation| ... } ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>
Lists attestors.
-
#update_attestor(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
Updates an attestor.
- #update_policy(request, options = nil) {|response, operation| ... } ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy
Methods included from Paths
#attestor_path, #policy_path, #project_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new BinauthzManagementService client object.
Examples
To create a new BinauthzManagementService client with the default configuration:
client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new
To create a new BinauthzManagementService client with a custom configuration:
client = ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.new do |config|
config.timeout = 10.0
end
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 170 def initialize # These require statements are intentionally placed here to initialize # the gRPC module only when it's required. # See https://github.com/googleapis/toolkit/issues/446 require "gapic/grpc" require "google/cloud/binaryauthorization/v1beta1/service_services_pb" # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the scope and endpoint are unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.scope == Client.configure.scope && @config.endpoint == Client.configure.endpoint && !@config.endpoint.split(".").first.include?("-") credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(String) || credentials.is_a?(Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @binauthz_management_service_stub = ::Gapic::ServiceStub.new( ::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementServiceV1Beta1::Stub, credentials: credentials, endpoint: @config.endpoint, channel_args: @config.channel_args, interceptors: @config.interceptors ) end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client class.
See Configuration for a description of the configuration fields.
Example
To modify the configuration for all BinauthzManagementService clients:
::Google::Cloud::BinaryAuthorization::V1beta1::BinauthzManagementService::Client.configure do |config|
config.timeout = 10.0
end
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 63 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "BinaryAuthorization", "V1beta1"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.get_policy.timeout = 600.0 default_config.rpcs.get_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.update_policy.timeout = 600.0 default_config.rpcs.update_policy.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.create_attestor.timeout = 600.0 default_config.rpcs.get_attestor.timeout = 600.0 default_config.rpcs.get_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.update_attestor.timeout = 600.0 default_config.rpcs.update_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.list_attestors.timeout = 600.0 default_config.rpcs.list_attestors.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config.rpcs.delete_attestor.timeout = 600.0 default_config.rpcs.delete_attestor.retry_policy = { initial_delay: 0.1, max_delay: 60.0, multiplier: 1.3, retry_codes: [4, 14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the BinauthzManagementService Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
145 146 147 148 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 145 def configure yield @config if block_given? @config end |
#create_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #create_attestor(parent: nil, attestor_id: nil, attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 392 def create_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::CreateAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_attestor..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.create_attestor.timeout, metadata: , retry_policy: @config.rpcs.create_attestor.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :create_attestor, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_attestor(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_attestor(name: nil) ⇒ ::Google::Protobuf::Empty
673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 673 def delete_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::DeleteAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_attestor..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.delete_attestor.timeout, metadata: , retry_policy: @config.rpcs.delete_attestor.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :delete_attestor, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #get_attestor(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 460 def get_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_attestor..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_attestor.timeout, metadata: , retry_policy: @config.rpcs.get_attestor.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :get_attestor, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#get_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #get_policy(name: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy
A policy specifies the attestors that must attest to a container image, before the project is allowed to deploy that image. There is at most one policy per project. All image admission requests are permitted if a project has no policy.
Gets the policy for this project. Returns a default policy if the project does not have one.
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 245 def get_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::GetPolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "name" => request.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.get_policy.timeout, metadata: , retry_policy: @config.rpcs.get_policy.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :get_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#list_attestors(request, options = nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor> #list_attestors(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::PagedEnumerable<::Google::Cloud::BinaryAuthorization::V1beta1::Attestor>
Lists attestors. Returns INVALID_ARGUMENT if the project does not exist.
604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 604 def list_attestors request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::ListAttestorsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_attestors..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "parent" => request.parent } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.list_attestors.timeout, metadata: , retry_policy: @config.rpcs.list_attestors.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :list_attestors, request, options: do |response, operation| response = ::Gapic::PagedEnumerable.new @binauthz_management_service_stub, :list_attestors, request, response, operation, yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_attestor(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor #update_attestor(attestor: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Attestor
529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 529 def update_attestor request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdateAttestorRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_attestor..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "attestor.name" => request.attestor.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_attestor.timeout, metadata: , retry_policy: @config.rpcs.update_attestor.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :update_attestor, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |
#update_policy(request, options = nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy #update_policy(policy: nil) ⇒ ::Google::Cloud::BinaryAuthorization::V1beta1::Policy
317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/google/cloud/binary_authorization/v1beta1/binauthz_management_service/client.rb', line 317 def update_policy request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::BinaryAuthorization::V1beta1::UpdatePolicyRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.update_policy..to_h # Set x-goog-api-client and x-goog-user-project headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::BinaryAuthorization::V1beta1::VERSION [:"x-goog-user-project"] = @quota_project_id if @quota_project_id header_params = { "policy.name" => request.policy.name } request_params_header = header_params.map { |k, v| "#{k}=#{v}" }.join("&") [:"x-goog-request-params"] ||= request_params_header .apply_defaults timeout: @config.rpcs.update_policy.timeout, metadata: , retry_policy: @config.rpcs.update_policy.retry_policy .apply_defaults metadata: @config., retry_policy: @config.retry_policy @binauthz_management_service_stub.call_rpc :update_policy, request, options: do |response, operation| yield response, operation if block_given? return response end rescue ::GRPC::BadStatus => e raise ::Google::Cloud::Error.from_error(e) end |